elemental_reference_energies_0K
    - created by Chris B on MSI at ~/projects/mus
    - MP and DMC standard calculations for all elements using PBE and R2SCAN

elemental_gibbs_energies_T
    - Gels.json from [here](https://github.com/CJBartel/predict-gibbs-energies)
    - from Chris B's [paper](https://www.nature.com/articles/s41467-018-06682-)